## -*- Perl -*-

use ExtUtils::MakeMaker qw(WriteMakefile);

my @ALLOWED_ARGS = ('DESTDIR', 'BINDIR', 'MANDIR');

# Parse command line arguments and store them as environment variables
while ($_ = shift) {
        my ($k,$v) = split(/=/, $_, 2);
        if (grep(/^$k$/, @ALLOWED_ARGS)) {
                $ENV{$k} = $v;
        }
}
$ENV{DESTDIR} =~ s/\/$//;
$ENV{BINDIR} =~ s/\/$//;
$ENV{MANDIR} =~ s/\/$//;

my $BINDIR = $ENV{BINDIR} || '/usr/local/bin';
my $MANDIR = $ENV{MANDIR} || '/usr/local/man';
my $DESTDIR = $ENV{DESTDIR} || '';

# Try to find all binary used by massadmin
my $ftp = `which ftp`;
chomp($ftp);
if (!$ftp) {
        die "NOTICE: This tool requires system command: ftp, can't find it in your path\n";
}
my $rsh = `which rsh`;
chomp($rsh);
if (!$rsh) {
        die "NOTICE: This tool requires the sysstat package, can't find rsh in your path\n";
}
my $sftp = `which sftp`;
chomp($sftp);
if (!$sftp) {
        die "NOTICE: This tool requires the sysstat package, can't find sftp in your path\n";
}
my $ssh = `which ssh`;
chomp($ssh);
if (!$ssh) {
        die "NOTICE: This tool requires the sysstat package, can't find ssh in your path\n";
}
my $scp = `which scp`;
chomp($scp);
if (!$scp) {
        die "NOTICE: This tool requires the sysstat package, can't find scp in your path\n";
}

unless(open(INST, ">install_all.sh")) {
        print "\nError: can't write post install file install_all.sh, $!\n";
        exit 0;
}
print INST qq{#!/bin/sh
if [ ! -d "$DESTDIR$BINDIR" ]; then
        mkdir -p $DESTDIR$BINDIR
fi
if [ ! -d "$DESTDIR$MANDIR" ]; then
        mkdir -p $DESTDIR$MANDIR
fi
pod2man doc/massadmin.pod doc/massadmin.1
install -m 755 massadmin $DESTDIR$BINDIR/
install -m 644 doc/massadmin.1 $DESTDIR$MANDIR/man1/
};
close(INST);
`chmod 755 install_all.sh`;

WriteMakefile(
	NAME         => "massadmin",
	DISTNAME     => "massadmin",
	VERSION_FROM => "massadmin",
	'DESTDIR'      => $ENV{DESTDIR},
	'INSTALLDIRS'  => $ENV{INSTALLDIRS},
	'clean'        => {FILES => "install_all.sh"},
	'PREREQ_PM'    => {
			'IO::Tty' => 1.03,
			'IO::Pty' => 1.03,
			'Expect' => 1.21,
			'Net::Ping' => 2.33,
			'Net::Telnet' => 3.03,
			'Proc::Queue' => '1.23',
			}, 
	dist         => {
			  'COMPRESS' => "gzip -9f", 'SUFFIX' => "gz",
			  'ZIP'=>'/usr/bin/zip','ZIPFLAGS'=>'-rl'
			},
	($] >= 5.005 ?
	(ABSTRACT   => "Parallelizes system commands on mass remote servers",
	AUTHOR     => "Gilles Darold <gilles\@darold.net>") : ()),
);

sub MY::install {
	my $self = shift;

	my $string = $self->MM::install;
	$string =~ s/(pure_install\s+)(.*)/$1 install_all $2/;

	return $string;
}

sub MY::postamble {
	my $postamble = <<'END';
install_all: install_all.sh
	sh install_all.sh
END
	return $postamble;
}


